.. the format shouldn't change since some handcoding have been done using the format of this file in the application itself ( or can update it if the application logic would also be changed to reflect the changes made here)

Changelog
=========

0.2.4 : *July 22, 2012*
-----------------------
column creation.
better postgresql constraints' view
bug fixes

0.2.3 : *May 27, 2012*
----------------------
Viewing, droping and reseting sequences. All under database overview

0.2.2 : *May 24, 2012*
----------------------
performance optimisations

rewrote the logic for making queries and generating views

now makes use of a lot of SQLAlchemy functions

bug fixes

0.2.1 : *May 3, 2012*
---------------------

wrote docs <tiote.readthedocs.org>

editing of table rows

refreshed sidebar

0.2.0 : *April 19, 2012*
------------------------
Project files can now be downloaded from pypi